MigrationName

Trait MigrationName 

pub trait MigrationName {
    // Required method
    fn name(&self) -> &str;
}
The name of a migration, used as its version key in the bookkeeping table.

Required Methods

fn name(&self) -> &str

The name, which must be unique across the migrator.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors